@@ -1,22 +1,9 @@
 /*
-   This file is part of the KDE Baloo project.
- * Copyright (C) 2015  Vishesh Handa <vhanda@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- *
- */
+    This file is part of the KDE Baloo project.
+    SPDX-FileCopyrightText: 2015 Vishesh Handa <vhanda@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "idtreedb.h"
 #include "enginedebug.h"
@@ -116,12 +103,13 @@ void IdTreeDB::del(quint64 docId)
 //
 class IdTreePostingIterator : public PostingIterator {
 public:
-    IdTreePostingIterator(const IdTreeDB& db, const QVector<quint64> list)
+    IdTreePostingIterator(const IdTreeDB& db, const QVector<quint64> &list)
         : m_db(db), m_pos(-1), m_idList(list) {}
 
     quint64 docId() const override {
-        if (m_pos >= 0 && m_pos < m_resultList.size())
+        if (m_pos >= 0 && m_pos < m_resultList.size()) {
             return m_resultList[m_pos];
+        }
         return 0;
     }
 
@@ -140,16 +128,18 @@ public:
             m_pos = 0;
         }
         else {
-            if (m_pos < m_resultList.size())
+            if (m_pos < m_resultList.size()) {
                 m_pos++;
-            else
+            } else {
                 m_resultList.clear();
+            }
         }
 
-        if (m_pos < m_resultList.size())
+        if (m_pos < m_resultList.size()) {
             return m_resultList[m_pos];
-        else
+        } else {
             return 0;
+        }
     }
 
 private:
@@ -178,8 +168,11 @@ QMap<quint64, QVector<quint64>> IdTreeDB::toTestMap() const
     QMap<quint64, QVector<quint64>> map;
     while (1) {
         int rc = mdb_cursor_get(cursor, &key, &val, MDB_NEXT);
+        if (rc == MDB_NOTFOUND) {
+            break;
+        }
         if (rc) {
-            qCDebug(ENGINE) << "PostingDB::toTestMap" << mdb_strerror(rc);
+            qCDebug(ENGINE) << "IdTreeDB::toTestMap" << mdb_strerror(rc);
             break;
         }
 
